@@ -1,9 +1,9 @@
 package Sah::Schema::date::dow_name::id;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Date-ID'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Day-of-week name (abbreviated or full, in Indonesian)',
@@ -38,7 +38,7 @@ Sah::Schema::date::dow_name::id - Day-of-week name (abbreviated or full, in Indo
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::date::dow_name::id (from Perl distribution Sah-Schemas-Date-ID), released on 2020-03-04.
+This document describes version 0.005 of Sah::Schema::date::dow_name::id (from Perl distribution Sah-Schemas-Date-ID), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -74,17 +74,17 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # valid
+ "mg"  # valid
 
- undef  # valid
+ "min"  # valid
 
- undef  # valid
+ "minggu"  # valid
 
- undef  # INVALID (English)
+ "sun"  # INVALID (English)
 
- undef  # INVALID
+ 1  # INVALID
 
 =head1 HOMEPAGE
 
