@@ -1,9 +1,9 @@
 package Sah::Schema::date::month_num::id;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Date-ID'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [int => {
     summary => 'Month number',
@@ -38,7 +38,7 @@ Sah::Schema::date::month_num::id - Month number
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::date::month_num::id (from Perl distribution Sah-Schemas-Date-ID), released on 2020-03-04.
+This document describes version 0.005 of Sah::Schema::date::month_num::id (from Perl distribution Sah-Schemas-Date-ID), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -74,21 +74,21 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # valid
+ "jan"  # valid, becomes 1
 
- undef  # valid
+ "AGU"  # valid, becomes 8
 
- undef  # INVALID
+ "aug"  # INVALID
 
- undef  # INVALID
+ 0  # INVALID
 
- undef  # valid
+ 1  # valid
 
- undef  # valid
+ 12  # valid
 
- undef  # INVALID
+ 13  # INVALID
 
 =head1 DESCRIPTION
 
