@@ -1,9 +1,9 @@
 package Sah::Schema::date::month_nums::en_or_id;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Date-ID'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = ['array' => {
     summary => 'Array of month numbers',
@@ -39,7 +39,7 @@ Sah::Schema::date::month_nums::en_or_id - Array of month numbers
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::date::month_nums::en_or_id (from Perl distribution Sah-Schemas-Date-ID), released on 2020-03-04.
+This document describes version 0.005 of Sah::Schema::date::month_nums::en_or_id (from Perl distribution Sah-Schemas-Date-ID), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -75,25 +75,25 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # valid
+ ""  # valid, becomes []
 
- undef  # valid
+ "jan"  # valid, becomes [1]
 
- undef  # valid
+ "AGU"  # valid, becomes [8]
 
- undef  # valid
+ "aug"  # valid, becomes [8]
 
- undef  # INVALID
+ 0  # INVALID
 
- undef  # valid
+ "1,agu"  # valid, becomes [1,8]
 
- undef  # valid
+ [1,"agu"]  # valid, becomes [1,8]
 
- undef  # valid
+ "1,12"  # valid, becomes [1,12]
 
- undef  # INVALID
+ "1,12,13"  # INVALID
 
- undef  # INVALID
+ [1,12,13]  # INVALID
 
 =head1 DESCRIPTION
 
